
From: Adrian Bunk <bunk@stusta.de>

  CC      kernel/power/swsusp.o
kernel/power/swsusp.c: In function `alloc_pagedir':
kernel/power/swsusp.c:608: sorry, unimplemented: inlining failed in call 
to 'free_pagedir': function body not available
kernel/power/swsusp.c:646: sorry, unimplemented: called from here
make[2]: *** [kernel/power/swsusp.o] Error 1

Signed-off-by: Adrian Bunk <bunk@stusta.de>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/kernel/power/swsusp.c |   30 ++++++++++++++----------------
 1 files changed, 14 insertions(+), 16 deletions(-)

diff -puN kernel/power/swsusp.c~swsusp-do-not-use-higher-order-memory-allocations-on-suspend-fix kernel/power/swsusp.c
--- 25/kernel/power/swsusp.c~swsusp-do-not-use-higher-order-memory-allocations-on-suspend-fix	2005-02-04 12:53:58.689486208 -0800
+++ 25-akpm/kernel/power/swsusp.c	2005-02-04 12:53:58.693485600 -0800
@@ -605,7 +605,20 @@ static int calc_nr(int nr_copy)
 	return nr_copy;
 }
 
-static inline void free_pagedir(struct pbe *pblist);
+/**
+ *	free_pagedir - free pages allocated with alloc_pagedir()
+ */
+
+static inline void free_pagedir(struct pbe *pblist)
+{
+	struct pbe *pbe;
+
+	while (pblist) {
+		pbe = pblist + PB_PAGE_SKIP;
+		pblist = pbe->next;
+		free_page((unsigned long)pblist);
+	}
+}
 
 /**
  *	alloc_pagedir - Allocate the page directory.
@@ -651,21 +664,6 @@ static struct pbe * alloc_pagedir(unsign
 }
 
 /**
- *	free_pagedir - free pages allocated with alloc_pagedir()
- */
-
-static inline void free_pagedir(struct pbe *pblist)
-{
-	struct pbe *pbe;
-
-	while (pblist) {
-		pbe = pblist + PB_PAGE_SKIP;
-		pblist = pbe->next;
-		free_page((unsigned long)pblist);
-	}
-}
-
-/**
  *	free_image_pages - Free pages allocated for snapshot
  */
 
_
